Release 1.4.1
-------------

(Published April, 2016)

The authoritative state for any known issue can be found in `GitHub issues <https://github.com/arista-eosplus/ztpserver/issues>`_.

Bug fixes
^^^^^^^^

* Pypi package missing plugins (`332 <https://github.com/arista-eosplus/ztpserver/issues/332>`_)
